
.. py:currentmodule:: pythreejs

CameraHelper
====================================================

.. Use autoclass to fill any memebers not manually specified.
   This ensures it picks up any members in overridden classes.

.. autohastraits:: CameraHelper(camera=None, )
    :members:
    :undoc-members:


    Inherits :py:class:`~pythreejs.Object3D`.

    Three.js docs: https://threejs.org/docs/#api/helpers/CameraHelper


    .. py:attribute:: camera

        .. sourcecode:: python

            Instance(Camera, allow_none=True).tag(sync=True, **widget_serialization)

